@@ -102,13 +102,24 @@ def teardown_request(exc):
 
 @token_blueprint.before_request
 @audit_blueprint.before_request
-@user_blueprint.before_request
 @system_blueprint.before_request
 @user_required
 def before_user_request():
     before_request()
 
 
+@user_blueprint.before_request
+@user_required
+def before_userendpoint_request():
+    before_request()
+    # DEL /user/ has no realm parameter and thus we need to create the user object this way.
+    if not request.User and request.method == "DELETE":
+        resolvername = getParam(request.all_data, "resolvername")
+        username = getParam(request.all_data, "username")
+        if resolvername and username:
+            request.User = User(login=username, resolver=resolvername)
+
+
 @resolver_blueprint.before_request
 @machineresolver_blueprint.before_request
 @machine_blueprint.before_request
