@@ -64,6 +64,7 @@ from privacyidea.lib.realm import get_default_realm
 from privacyidea.lib.subscriptions import subscription_status
 from privacyidea.lib.utils import create_img
 from privacyidea.lib.config import get_privacyidea_node
+from privacyidea.lib.tokenclass import ROLLOUTSTATE
 
 log = logging.getLogger(__name__)
 
@@ -165,7 +166,7 @@ def sign_response(request, response):
         log.debug(traceback.format_exc())
         return response
 
-    request.all_data = get_all_params(request.values, request.data)
+    request.all_data = get_all_params(request)
     # response can be either a Response object or a Tuple (Response, ErrorID)
     response_value = 200
     response_is_tuple = False
@@ -444,7 +445,7 @@ def offline_info(request, response):
     """
     This decorator is used with the function /validate/check.
     It is not triggered by an ordinary policy but by a MachineToken definition.
-    If for the given Client and Token an offline application is defined,
+    If for the given Token an offline application is defined,
     the response is enhanced with the offline information - the hashes of the
     OTP.
 
@@ -452,17 +453,10 @@ def offline_info(request, response):
     content = response.json
     # check if the authentication was successful
     if content.get("result").get("value") is True and g.client_ip:
-        # If there is no remote address, we can not determine
-        # offline information
-        client_ip = netaddr.IPAddress(g.client_ip)
         # check if there is a MachineToken definition
         serial = content.get("detail", {}).get("serial")
         try:
-            # if the hostname can not be identified, there might be no
-            # offline definition!
-            hostname = get_hostname(ip=client_ip)
-            auth_items = get_auth_items(hostname=hostname, ip=client_ip,
-                                        serial=serial, application="offline",
+            auth_items = get_auth_items(serial=serial, application="offline",
                                         challenge=request.all_data.get("pass"))
             if auth_items:
                 content["auth_items"] = auth_items
@@ -594,6 +588,8 @@ def get_webui_settings(request, response):
         content["result"]["value"]["show_seed"] = show_seed
         content["result"]["value"]["show_node"] = get_privacyidea_node() if show_node else ""
         content["result"]["value"]["subscription_status"] = subscription_status()
+        content["result"]["value"]["subscription_status_push"] = subscription_status("privacyidea authenticator",
+                                                                                     tokentype="push")
         content["result"]["value"]["qr_image_android"] = qr_image_android
         content["result"]["value"]["qr_image_ios"] = qr_image_ios
         content["result"]["value"]["qr_image_custom"] = qr_image_custom
@@ -767,3 +763,51 @@ def is_authorized(request, response):
             raise ValidateError("User is not authorized to authenticate under these conditions.")
 
     return response
+
+
+def check_verify_enrollment(request, response):
+    """
+    This policy decorator is used in the ENROLL scope to
+    decorate the /token/init
+    If will check for action=verify_enrollment and ask the user
+    in a 2nd step to provide information to verify, that the token was successfully enrolled.
+
+    :param request:
+    :param response:
+    :return:
+    """
+    serial = response.json.get("detail").get("serial")
+    verify = request.all_data.get("verify")
+    if verify:
+        # In case we are in a 2nd step verification, we must early exit
+        return response
+    tokenobj_list = get_tokens(serial=serial)
+    if len(tokenobj_list) == 1:
+        tokenobj = tokenobj_list[0]
+        # check if this token type can do verify enrollment
+        if tokenobj.can_verify_enrollment:
+            # Get policies
+            verify_pol_dict = Match.user(g, scope=SCOPE.ENROLL, action=ACTION.VERIFY_ENROLLMENT,
+                                         user_object=request.User).action_values(unique=False,
+                                                                                 allow_white_space_in_action=True,
+                                                                                 write_to_audit_log=False)
+            # verify_pol_dict.keys() is a list of actions from several policies. It
+            # could look like this:
+            # ["hotp totp", "hotp email"]
+            do_verify_enrollment = False
+            for toks in verify_pol_dict:
+                if tokenobj.get_tokentype().upper() in [x.upper() for x in toks.split(" ")]:
+                    # This token is supposed to do verify enrollment
+                    do_verify_enrollment = True
+                    g.audit_object.add_policy(verify_pol_dict.get(toks))
+            if do_verify_enrollment:
+                content = response.json
+                content["detail"]["verify"] = tokenobj.prepare_verify_enrollment()
+                content["detail"]["rollout_state"] = ROLLOUTSTATE.VERIFYPENDING
+                tokenobj.token.rollout_state = ROLLOUTSTATE.VERIFYPENDING
+                tokenobj.token.save()
+                response.set_data(json.dumps(content))
+    else:
+        log.warning("No distinct token object found in enrollment response!")
+
+    return response
