@@ -77,13 +77,14 @@ from privacyidea.lib.user import (get_user_from_param, get_default_realm,
                                   split_user, User)
 from privacyidea.lib.token import (get_tokens, get_realms_of_token, get_token_type, get_token_owner)
 from privacyidea.lib.utils import (parse_timedelta, is_true, generate_charlists_from_pin_policy,
-                                   check_pin_contents, get_module_class,
+                                   get_module_class,
                                    determine_logged_in_userparams, parse_string_to_dict)
 from privacyidea.lib.crypto import generate_password
 from privacyidea.lib.auth import ROLE
 from privacyidea.api.lib.utils import getParam, attestation_certificate_allowed, is_fqdn
 from privacyidea.lib.clientapplication import save_clientapplication
 from privacyidea.lib.config import (get_token_class)
+from privacyidea.lib.tokenclass import ROLLOUTSTATE
 import functools
 import jwt
 import re
@@ -506,37 +507,52 @@ def init_token_defaults(request=None, action=None):
     return True
 
 
-def init_registrationcode_length_contents(request=None, action=None):
+def init_token_length_contents(request=None, action=None):
     """
     This policy function is to be used as a decorator in the API token init function.
 
-    If there is a valid policy set the action values of REGISTRATIONCODE_LENGTH
-    and REGISTRATIONCODE_CONTENTS are added to request.all_data as
+    It can set the parameters for automatic code or password created in regards to length and
+    contents for the tokentypes 'registration' and 'pw'.
+
+    If there is a valid policy set the action values of REGISTRATIONCODE_LENGTH / PASSWORD_LENGTH
+    and REGISTRATIONCODE_CONTENTS / PASSWORD_CONTENTS are added to request.all_data as
 
     { 'registration.length': '10', 'registration.contents': 'cn' }
+    or
+    { 'pw.length': '10', 'pw.contents': 'cn' }
     """
-    from privacyidea.lib.tokens.registrationtoken import DEFAULT_LENGTH, DEFAULT_CONTENTS
     no_content_policy = True
     no_length_policy = True
     params = request.all_data
     tokentype = params.get("type")
-    if tokentype == "registration":
-        user_object = get_user_from_param(params)
-        length_pols = Match.user(g, scope=SCOPE.ENROLL, action=ACTION.REGISTRATIONCODE_LENGTH,
-                                user_object=user_object).action_values(unique=True)
-        if len(length_pols) == 1:
-            request.all_data[ACTION.REGISTRATIONCODE_LENGTH] = list(length_pols)[0]
-            no_length_policy = False
-        content_pols = Match.user(g, scope=SCOPE.ENROLL, action=ACTION.REGISTRATIONCODE_CONTENTS,
-                                user_object=user_object).action_values(unique=True)
-        if len(content_pols) == 1:
-            request.all_data[ACTION.REGISTRATIONCODE_CONTENTS] = list(content_pols)[0]
-            no_content_policy = False
+
+    if tokentype == 'registration':
+        from privacyidea.lib.tokens.registrationtoken import DEFAULT_LENGTH, DEFAULT_CONTENTS
+        length_action = ACTION.REGISTRATIONCODE_LENGTH
+        contents_action = ACTION.REGISTRATIONCODE_CONTENTS
+    elif tokentype == 'pw':
+        from privacyidea.lib.tokens.passwordtoken import DEFAULT_LENGTH, DEFAULT_CONTENTS
+        length_action = ACTION.PASSWORD_LENGTH
+        contents_action = ACTION.PASSWORD_CONTENTS
+    else:
+        return True
+
+    user_object = get_user_from_param(params)
+    length_pols = Match.user(g, scope=SCOPE.ENROLL, action=length_action,
+                            user_object=user_object).action_values(unique=True)
+    if len(length_pols) == 1:
+        request.all_data[length_action] = list(length_pols)[0]
+        no_length_policy = False
+    content_pols = Match.user(g, scope=SCOPE.ENROLL, action=contents_action,
+                            user_object=user_object).action_values(unique=True)
+    if len(content_pols) == 1:
+        request.all_data[contents_action] = list(content_pols)[0]
+        no_content_policy = False
     # if there is no policy, set defaults.
     if no_length_policy:
-        request.all_data[ACTION.REGISTRATIONCODE_LENGTH] = DEFAULT_LENGTH
+        request.all_data[length_action] = DEFAULT_LENGTH
     if no_content_policy:
-        request.all_data[ACTION.REGISTRATIONCODE_CONTENTS] = DEFAULT_CONTENTS
+        request.all_data[contents_action] = DEFAULT_CONTENTS
     return True
 
 
@@ -676,6 +692,34 @@ def twostep_enrollment_parameters(request=None, action=None):
                 request.all_data[parameter] = list(action_values)[0]
 
 
+def verify_enrollment(request=None, action=None):
+    """
+    This is used to verify an already enrolled token.
+    The parameter "verify" is used to do so. If successful,
+    the current rollout_state "verify" of the token will be changed to "enrolled".
+
+    :param request:
+    :param action:
+    :return:
+    """
+    serial = getParam(request.all_data, "serial", optional)
+    verify = getParam(request.all_data, "verify", optional)
+    if verify and serial:
+        # Only now, we check if we need to verify
+        tokenobj_list = get_tokens(serial=serial)
+        if len(tokenobj_list) == 1:
+            tokenobj = tokenobj_list[0]
+            if tokenobj.rollout_state == ROLLOUTSTATE.VERIFYPENDING:
+                log.debug("Verifying the token enrollment for token {0!s}.".format(serial))
+                r = tokenobj.verify_enrollment(verify)
+                log.info("Result of enrollment verification for token {0!s}: {1!s}".format(serial, r))
+                if r:
+                    tokenobj.token.rollout_state = ROLLOUTSTATE.ENROLLED
+                else:
+                    from privacyidea.lib.error import ParameterError
+                    raise ParameterError("Verification of the new token failed.")
+
+
 def check_max_token_user(request=None, action=None):
     """
     Pre Policy
@@ -1155,12 +1199,6 @@ def check_base_action(request=None, action=None, anonymous=False):
             realm = get_realms_of_token(params.get("serial"),
                                         only_first_realm=True)
 
-        # get the realm by the serial, while the serial is part of the URL like
-        # DELETE /token/serial
-        if not realm and request.view_args and request.view_args.get("serial"):
-            realm = get_realms_of_token(request.view_args.get("serial"),
-                                        only_first_realm=True)
-
     # In this case we do not pass the user_object, since the realm is also determined
     # by the pure serial number given.
     action_allowed = Match.generic(g, scope=role,
@@ -2104,3 +2142,27 @@ def required_piv_attestation(request, action=None):
         # Add parameter verify_attestation
         request.all_data["verify_attestation"] = REQUIRE_ACTIONS.VERIFY in list(require_att) or \
                                                  REQUIRE_ACTIONS.REQUIRE_AND_VERIFY in list(require_att)
+
+
+def hide_tokeninfo(request=None, action=None):
+    """
+    This decorator checks for the policy `hide_tokeninfo` and sets the
+    `hidden_tokeninfo` parameter.
+
+    The given tokeninfo keys will be removed from the response.
+
+    The decorator wraps GET /token/
+
+    :param request: The request that is intercepted during the API call
+    :type request: Request Object
+    :param action: An optional Action
+    :type action: str
+    :return: Always true. Modifies the parameter `request`
+    :rtype: bool
+    """
+    hidden_fields = Match.admin_or_user(g, action=ACTION.HIDE_TOKENINFO,
+                                        user_obj=request.User)\
+        .action_values(unique=False)
+
+    request.all_data['hidden_tokeninfo'] = list(hidden_fields)
+    return True
