@@ -98,7 +98,8 @@ from privacyidea.lib.policydecorators import (libpolicy,
                                               auth_cache,
                                               config_lost_token,
                                               reset_all_user_tokens)
-from privacyidea.lib.challengeresponsedecorators import generic_challenge_response_reset_pin
+from privacyidea.lib.challengeresponsedecorators import (generic_challenge_response_reset_pin,
+                                                         generic_challenge_response_resync)
 from privacyidea.lib.tokenclass import DATE_FORMAT
 from privacyidea.lib.tokenclass import TOKENKIND
 from dateutil.tz import tzlocal
@@ -443,9 +444,10 @@ def get_tokens(tokentype=None, realm=None, assigned=None, user=None,
 
 @log_with(log)
 def get_tokens_paginate(tokentype=None, realm=None, assigned=None, user=None,
-                serial=None, active=None, resolver=None, rollout_state=None,
-                sortby=Token.serial, sortdir="asc", psize=15,
-                page=1, description=None, userid=None, allowed_realms=None, tokeninfo=None):
+                        serial=None, active=None, resolver=None, rollout_state=None,
+                        sortby=Token.serial, sortdir="asc", psize=15,
+                        page=1, description=None, userid=None, allowed_realms=None,
+                        tokeninfo=None, hidden_tokeninfo=None):
     """
     This function is used to retrieve a token list, that can be displayed in
     the Web UI. It supports pagination.
@@ -491,9 +493,14 @@ def get_tokens_paginate(tokentype=None, realm=None, assigned=None, user=None,
                                 allowed_realms=allowed_realms)
 
     if isinstance(sortby, string_types):
-        # convert the string to a Token column
+        # check that the sort column exists and convert it to a Token column
         cols = Token.__table__.columns
-        sortby = cols.get(sortby)
+        if sortby in cols:
+            sortby = cols.get(sortby)
+        else:
+            log.warning('Unknown sort column "{0!s}". Using "serial" '
+                        'instead.'.format(sortby))
+            sortby = Token.serial
 
     if sortdir == "desc":
         sql_query = sql_query.order_by(sortby.desc())
@@ -531,6 +538,11 @@ def get_tokens_paginate(tokentype=None, realm=None, assigned=None, user=None,
                 log.debug(traceback.format_exc())
                 token_dict["username"] = "**resolver error**"
 
+            if hidden_tokeninfo:
+                for key in list(token_dict['info']):
+                    if key in hidden_tokeninfo:
+                        token_dict['info'].pop(key)
+
             token_list.append(token_dict)
 
     ret = {"tokens": token_list,
@@ -579,7 +591,7 @@ def get_tokens_from_serial_or_user(serial, user, **kwargs):
 def get_token_type(serial):
     """
     Returns the tokentype of a given serial number. If the token does
-    not exist or can not be deterimined, an empty string is returned.
+    not exist or can not be determined, an empty string is returned.
 
     :param serial: the serial number of the to be searched token
     :type serial: string
@@ -1124,24 +1136,7 @@ def remove_token(serial=None, user=None):
 
     # Delete challenges of such a token
     for tokenobject in tokenobject_list:
-        # delete the challenge
-        Challenge.query.filter(Challenge.serial == tokenobject.get_serial(
-
-        )).delete()
-
-        # due to legacy SQLAlchemy it could happen that the
-        # foreign key relation could not be deleted
-        # so we do this manualy
-
-        # delete references to client machines
-        MachineToken.query.filter(MachineToken.token_id ==
-                                  tokenobject.token.id).delete()
-        TokenRealm.query.filter(TokenRealm.token_id ==
-                                tokenobject.token.id).delete()
-        TokenOwner.query.filter(TokenOwner.token_id ==
-                                tokenobject.token.id).delete()
-
-        tokenobject.token.delete()
+        tokenobject.delete_token()
 
     return token_count
 
@@ -1270,7 +1265,7 @@ def unassign_token(serial, user=None):
 @log_with(log)
 def resync_token(serial, otp1, otp2, options=None, user=None):
     """
-    Resyncronize the token of the given serial number and user by searching the
+    Resynchronize the token of the given serial number and user by searching the
     otp1 and otp2 in the future otp values.
 
     :param serial: token serial number (exact)
@@ -1303,7 +1298,7 @@ def reset_token(serial, user=None):
 
     :param serial: serial number (exact)
     :param user:
-    :return: The number of tokens, that were resetted
+    :return: The number of tokens, that were reset
     :rtype: int
     """
     tokenobject_list = get_tokens_from_serial_or_user(serial=serial, user=user)
@@ -2085,17 +2080,17 @@ def create_challenges_from_tokens(token_list, reply_dict, options=None):
     for token_obj in token_list:
         # Check if the max auth is succeeded
         if token_obj.check_all(message_list):
-            r_chal, message, transaction_id, attributes = \
+            r_chal, message, transaction_id, challenge_info = \
                 token_obj.create_challenge(
                     transactionid=transaction_id, options=options)
             # Add the reply to the response
             message_list.append(message)
             if r_chal:
-                challenge_info = {}
+                challenge_info = challenge_info or {}
                 challenge_info["transaction_id"] = transaction_id
-                challenge_info["attributes"] = attributes
                 challenge_info["serial"] = token_obj.token.serial
                 challenge_info["type"] = token_obj.get_tokentype()
+                challenge_info["client_mode"] = token_obj.client_mode
                 challenge_info["message"] = message
                 # If exist, add next pin and next password change
                 next_pin = token_obj.get_tokeninfo(
@@ -2111,6 +2106,7 @@ def create_challenges_from_tokens(token_list, reply_dict, options=None):
                     challenge_info["password_change"] = \
                         token_obj.is_pin_change(
                             password=True)
+                # FIXME: This is deprecated and should be remove one day
                 reply_dict.update(challenge_info)
                 reply_dict["multi_challenge"].append(challenge_info)
     if message_list:
@@ -2141,6 +2137,7 @@ def weigh_token_type(token_obj):
 @log_with(log)
 @libpolicy(reset_all_user_tokens)
 @libpolicy(generic_challenge_response_reset_pin)
+@libpolicy(generic_challenge_response_resync)
 def check_token_list(tokenobject_list, passw, user=None, options=None, allow_reset_all_tokens=False):
     """
     this takes a list of token objects and tries to find the matching token
