@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 #
+#  2022-02-03 Cornelius Kölbel <cornelius.koelbel@netknights.it>
+#             Add verified enrollment
 #  2018-01-21 Cornelius Kölbel <cornelius.koelbel@netknights.it>
 #             Implement tokenkind. Token can be hardware, software or virtual
 #  2017-07-08 Cornelius Kölbel <cornelius.koelbel@netknights.it>
@@ -95,7 +97,7 @@ from privacyidea.lib.crypto import (encryptPassword, decryptPassword,
                                     generate_otpkey)
 from .policydecorators import libpolicy, auth_otppin, challenge_response_allowed
 from .decorators import check_token_locked
-from dateutil.parser import parse as parse_date_string
+from dateutil.parser import parse as parse_date_string, ParserError
 from dateutil.tz import tzlocal, tzutc
 from privacyidea.lib.utils import (is_true, decode_base32check,
                                    to_unicode, create_img, parse_timedelta,
@@ -125,21 +127,43 @@ class TOKENKIND(object):
     VIRTUAL = "virtual"
 
 
-class TOKENMODE(object):
+class AUTHENTICATIONMODE(object):
     AUTHENTICATE = 'authenticate'
     CHALLENGE = 'challenge'
     # If the challenge is answered out of band
     OUTOFBAND = 'outofband'
 
 
+class CLIENTMODE(object):
+    """
+    This informs privacyIDEA clients how to
+    handle challenge-responses
+    """
+    INTERACTIVE = 'interactive'
+    POLL = 'poll'
+    U2F = 'u2f'
+    WEBAUTHN = 'webauthn'
+
+    
+class ROLLOUTSTATE(object):
+    CLIENTWAIT = 'clientwait'
+    PENDING = 'pending'
+    # This means the user needs to authenticate to verify that the token was successfully enrolled.
+    VERIFYPENDING = 'verify'
+    ENROLLED = 'enrolled'
+
+
 class TokenClass(object):
 
     # Class properties
     using_pin = True
     hKeyRequired = False
-    mode = [TOKENMODE.AUTHENTICATE, TOKENMODE.CHALLENGE]
+    mode = [AUTHENTICATIONMODE.AUTHENTICATE, AUTHENTICATIONMODE.CHALLENGE]
+    client_mode = CLIENTMODE.INTERACTIVE
     # Usually a token will be checked in the lib:check_token_list, even if it is disabled
     check_if_disabled = True
+    # If the token provides means that the user has to prove/verify that the token was successfully enrolled.
+    can_verify_enrollment = False
 
     @log_with(log)
     def __init__(self, db_token):
@@ -175,7 +199,7 @@ class TokenClass(object):
 
     @classmethod
     def is_outofband(cls):
-        return TOKENMODE.OUTOFBAND in cls.mode
+        return AUTHENTICATIONMODE.OUTOFBAND in cls.mode
 
     @staticmethod
     def get_class_type():
@@ -202,9 +226,18 @@ class TokenClass(object):
         :return: None
         """
         (uid, resolvertype, resolvername) = user.get_user_identifiers()
-        r = TokenOwner(token_id=self.token.id,
-                       user_id=uid, resolver=resolvername,
-                       realmname=user.realm).save()
+        # prevent to init update a token changing the token owner
+        # FIXME: We need to remove this, if we one day want to assign several users to one token
+        if self.user and self.user != user:
+            log.info(u"The token with serial {0!s} is already assigned "
+                     u"to user {1!s}. Can not assign to {2!s}.".format(self.token.serial, self.user, user))
+            raise TokenAdminError("This token is already assigned to another user.")
+
+        if not self.user:
+            # If the tokenowner is not set yet, set it / avoid setting the same tokenowner multiple times
+            r = TokenOwner(token_id=self.token.id,
+                           user_id=uid, resolver=resolvername,
+                           realmname=user.realm).save()
         # set the tokenrealm
         self.set_realms([user.realm])
 
@@ -492,6 +525,7 @@ class TokenClass(object):
         :type: param: dict
         """
         tdesc = getParam(param, "description", optional)
+        rollover = getParam(param, "rollover", optional)
         if tdesc is not None:
             self.token.set_description(tdesc)
 
@@ -510,6 +544,7 @@ class TokenClass(object):
         otpKey = getParam(param, "otpkey", optional)
         genkey = is_true(getParam(param, "genkey", optional))
         twostep_init = is_true(getParam(param, "2stepinit", optional))
+        verify = getParam(param, "verify", optional)
         otpkeyformat = getParam(param, "otpkeyformat", optional)
 
         if otpKey is not None and otpkeyformat is not None:
@@ -517,7 +552,10 @@ class TokenClass(object):
             otpKey = self.decode_otpkey(otpKey, otpkeyformat)
 
         if twostep_init:
-            if self.token.rollout_state == "clientwait":
+            if is_true(rollover):
+                # We reset the rollout state
+                self.token.rollout_state = None
+            if self.token.rollout_state == ROLLOUTSTATE.CLIENTWAIT:
                 # We do not do 2stepinit in the second step
                 raise ParameterError("2stepinit is only to be used in the "
                                      "first initialization step.")
@@ -538,12 +576,12 @@ class TokenClass(object):
         if otpKey is None and genkey:
             otpKey = self._genOtpKey_(key_size)
 
-        # otpKey still None?? - raise the exception
-        if otpKey is None and self.hKeyRequired is True:
+        # otpKey still None?? - raise the exception, if an otpkey is required and we are not in verify state
+        if otpKey is None and self.hKeyRequired is True and not verify:
             otpKey = getParam(param, "otpkey", required)
 
         if otpKey is not None:
-            if self.token.rollout_state == "clientwait":
+            if self.token.rollout_state == ROLLOUTSTATE.CLIENTWAIT:
                 # If we have otpkey and the token is in the enrollment-state
                 # generate the new key
                 server_component = to_unicode(self.token.get_otpkey().getKey())
@@ -558,7 +596,7 @@ class TokenClass(object):
 
         if twostep_init:
             # After the key is generated, we set "waiting for the client".
-            self.token.rollout_state = "clientwait"
+            self.token.rollout_state = ROLLOUTSTATE.CLIENTWAIT
 
         pin = getParam(param, "pin", optional)
         if pin is not None:
@@ -642,6 +680,10 @@ class TokenClass(object):
     def is_active(self):
         return self.token.active
 
+    @property
+    def rollout_state(self):
+        return self.token.rollout_state
+
     def is_fit_for_challenge(self, messages, options=None):
         """
         This method is called if a cryptographically matching response to a challenge was found.
@@ -1093,7 +1135,7 @@ class TokenClass(object):
         Checks if we should reset the failcounter due to the
         FAILCOUNTER_CLEAR_TIMEOUT
 
-        :return: True, if the failcounter was resetted
+        :return: True, if the failcounter was reset
         """
         timeout = 0
         try:
@@ -1190,6 +1232,8 @@ class TokenClass(object):
             message_list.append("Failcounter exceeded")
         elif not self.check_validity_period():
             message_list.append("Outside validity period")
+        elif self.rollout_state in [ROLLOUTSTATE.CLIENTWAIT, ROLLOUTSTATE.VERIFYPENDING]:
+            message_list.append("Token is not yet enrolled")
         else:
             r = True
         if not r:
@@ -1315,7 +1359,7 @@ class TokenClass(object):
 
     def get_init_detail(self, params=None, user=None):
         """
-        to complete the token initialization, the response of the initialisation
+        to complete the token initialization, the response of the initialization
         should be build by this token specific method.
         This method is called from api/token after the token is enrolled
 
@@ -1541,20 +1585,20 @@ class TokenClass(object):
         :param transactionid: the id of this challenge
         :param options: the request context parameters / data
         :type options: dict
-        :return: tuple of (bool, message, transactionid, attributes)
+        :return: tuple of (bool, message, transactionid, reply_dict)
         :rtype: tuple
 
         The return tuple builds up like this:
         ``bool`` if submit was successful;
         ``message`` which is displayed in the JSON response;
-        additional ``attributes``, which are displayed in the JSON response.
+        additional challenge ``reply_dict``, which are displayed in the JSON challenges response.
         """
         options = options or {}
         message = get_action_values_from_options(SCOPE.AUTH,
                                                  ACTION.CHALLENGETEXT,
                                                  options) or _('please enter otp: ')
         data = None
-        attributes = None
+        reply_dict = {}
 
         validity = int(get_from_config('DefaultChallengeValidityTime', 120))
         tokentype = self.get_tokentype().lower()
@@ -1571,7 +1615,7 @@ class TokenClass(object):
                                  validitytime=validity)
         db_challenge.save()
         self.challenge_janitor()
-        return True, message, db_challenge.transaction_id, attributes
+        return True, message, db_challenge.transaction_id, reply_dict
 
     def get_as_dict(self):
         """
@@ -1659,7 +1703,10 @@ class TokenClass(object):
         than the specified time delta which is passed as 10h, 7d or 1y.
 
         It returns True, if the last authentication with this token is
-        **newer*** than the specified delta.
+        **newer** than the specified delta or by any chance exactly the same.
+
+        It returns False, if the last authentication is older or
+        if the data in the token can not be parsed.
 
         :param last_auth: 10h, 7d or 1y
         :type last_auth: basestring
@@ -1678,7 +1725,12 @@ class TokenClass(object):
                       "tdelta %s: %s" % (self.token.serial, tdelta,
                                          date_s))
             # parse the string from the database
-            last_success_auth = parse_date_string(date_s)
+            try:
+                last_success_auth = parse_date_string(date_s)
+            except ParserError:
+                log.info("Failed to parse the date in 'last_auth' of token {0!s}.".format(self.token.serial))
+                return False
+
             if not last_success_auth.tzinfo:
                 # the date string has no timezone, default timezone is UTC
                 # We need to set the timezone manually
@@ -1753,3 +1805,27 @@ class TokenClass(object):
             params["otplen"] = 6
 
         return params
+
+    def prepare_verify_enrollment(self):
+        """
+        This is called, if the token should be enrolled in a way, that the user
+        needs to provide a proof, that the server can verify, that the token
+        was successfully enrolled. E.g. with HOTP tokens the user might need to provide
+        a correct OTP value.
+
+        The returned dictionary is added to the response in "detail" -> "verify".
+
+        :return: A dictionary with information that is needed to trigger the verification.
+        """
+        return None
+
+    def verify_enrollment(self, response):
+        """
+        This is called during the 2nd step of the verified enrollment.
+        This method verifies the actual response from the user.
+        Returns true, if the verification was successful.
+
+        :param response: The response given by the user
+        :return: True
+        """
+        return False
