@@ -69,6 +69,7 @@ import logging
 import traceback
 import datetime
 from privacyidea.lib.tokens.smstoken import HotpTokenClass
+from privacyidea.lib.tokens.hotptoken import VERIFY_ENROLLMENT_MESSAGE
 from privacyidea.lib.config import get_from_config
 from privacyidea.api.lib.utils import getParam
 from privacyidea.lib.utils import is_true, create_tag_dict
@@ -99,6 +100,8 @@ class EmailTokenClass(HotpTokenClass):
     """
 
     EMAIL_ADDRESS_KEY = "email"
+    # The HOTP token provides means to verify the enrollment
+    can_verify_enrollment = True
 
     def __init__(self, aToken):
         HotpTokenClass.__init__(self, aToken)
@@ -159,14 +162,15 @@ class EmailTokenClass(HotpTokenClass):
                'policy': {SCOPE.AUTH: {
                    EMAILACTION.EMAILTEXT: {
                        'type': 'str',
-                       'desc': _('The text that will be sent via EMail for'
-                                 ' an EMail token. Use <otp> and <serial> '
-                                 'as parameters. You may also specify a filename '
-                                 'as email template starting with "file:".')},
+                       'desc': _('The text that will be sent via EMail for '
+                                 'an EMail-token. Several tags like {otp} and '
+                                 '{serial} can be used as parameters. You may '
+                                 'also specify a filename as email template '
+                                 'starting with "file:".')},
                    EMAILACTION.EMAILSUBJECT: {
                        'type': 'str',
-                       'desc': _('The subject of the EMail for'
-                                 ' an EMail token. Use <otp> and <serial> '
+                       'desc': _('The subject of the EMail for '
+                                 'an EMail token. Use tags like {otp} and {serial} '
                                  'as parameters.')},
                    EMAILACTION.EMAILAUTO: {
                        'type': 'bool',
@@ -213,18 +217,20 @@ class EmailTokenClass(HotpTokenClass):
         :return: nothing
 
         """
-        if getParam(param, "dynamic_email", optional=True):
-            self.add_tokeninfo("dynamic_email", True)
-        else:
-            # specific - e-mail
-            self._email_address = getParam(param,
-                                           self.EMAIL_ADDRESS_KEY,
-                                           optional=False)
+        verify = getParam(param, "verify", optional=True)
+        if not verify:
+            if getParam(param, "dynamic_email", optional=True):
+                self.add_tokeninfo("dynamic_email", True)
+            else:
+                # specific - e-mail
+                self._email_address = getParam(param,
+                                               self.EMAIL_ADDRESS_KEY,
+                                               optional=False)
 
-        # in case of the e-mail token, only the server must know the otpkey
-        # thus if none is provided, we let create one (in the TokenClass)
-        if 'genkey' not in param and 'otpkey' not in param:
-            param['genkey'] = 1
+            # in case of the e-mail token, only the server must know the otpkey
+            # thus if none is provided, we let create one (in the TokenClass)
+            if 'genkey' not in param and 'otpkey' not in param:
+                param['genkey'] = 1
 
         HotpTokenClass.update(self, param, reset_failcount)
         return
@@ -252,14 +258,14 @@ class EmailTokenClass(HotpTokenClass):
         :param transactionid: the id of this challenge
         :param options: the request context parameters / data
             You can pass ``exception=1`` to raise an exception, if
-            the SMS could not be sent. Otherwise the message is contained in the response.
+            the Email could not be sent.
         :return: tuple
             of (success, message, transactionid, attributes)
 
                 * success: if submit was successful
                 * message: the text submitted to the user
                 * transactionid: the given or generated transactionid
-                * attributes: additional attributes, which are displayed in the output
+                * reply_dict: additional dictionary, which is added to the response
         :rtype: tuple(bool, str, str, dict)
         """
         success = False
@@ -268,7 +274,7 @@ class EmailTokenClass(HotpTokenClass):
                                                         "{0!s}_{1!s}".format(self.get_class_type(),
                                                                              ACTION.CHALLENGETEXT),
                                                         options) or _("Enter the OTP from the Email:")
-        attributes = {'state': transactionid}
+        reply_dict = {'attributes': {'state': transactionid}}
         validity = int(get_from_config("email.validtime", 120))
 
         if self.is_active() is True:
@@ -304,9 +310,9 @@ class EmailTokenClass(HotpTokenClass):
                     mimetype=mimetype)
 
             except Exception as e:
-                info = ("The PIN was correct, but the "
-                        "EMail could not be sent: %r" % e)
-                log.warning(info)
+                info = _("The PIN was correct, but the "
+                         "EMail could not be sent!")
+                log.warning(info + " ({0!s})".format(e))
                 log.debug(u"{0!s}".format(traceback.format_exc()))
                 return_message = info
                 if is_true(options.get("exception")):
@@ -314,9 +320,9 @@ class EmailTokenClass(HotpTokenClass):
 
         expiry_date = datetime.datetime.now() + \
                                     datetime.timedelta(seconds=validity)
-        attributes['valid_until'] = "{0!s}".format(expiry_date)
+        reply_dict['attributes']['valid_until'] = "{0!s}".format(expiry_date)
 
-        return success, return_message, transactionid, attributes
+        return success, return_message, transactionid, reply_dict
 
     @log_with(log)
     @check_token_locked
@@ -434,8 +440,8 @@ class EmailTokenClass(HotpTokenClass):
         tags = create_tag_dict(serial=serial,
                                tokenowner=self.user,
                                tokentype=self.get_tokentype(),
-                               recipient={"givenname": self.user.info.get("givenname"),
-                                          "surname": self.user.info.get("surname")},
+                               recipient={"givenname": self.user.info.get("givenname") if self.user else "",
+                                          "surname": self.user.info.get("surname") if self.user else ""},
                                escape_html=mimetype.lower() == "html")
 
         message = message.format(otp=otp, **tags)
@@ -487,3 +493,17 @@ class EmailTokenClass(HotpTokenClass):
             description = TEST_SUCCESSFUL
 
         return r, description
+
+    def prepare_verify_enrollment(self):
+        """
+        This is called, if the token should be enrolled in a way, that the user
+        needs to provide a proof, that the server can verify, that the token
+        was successfully enrolled.
+        The email token needs to send an email with OTP.
+
+        The returned dictionary is added to the response in "detail" -> "verify".
+
+        :return: A dictionary with information that is needed to trigger the verification.
+        """
+        self.create_challenge()
+        return {"message": VERIFY_ENROLLMENT_MESSAGE}
