@@ -18,8 +18,10 @@
  * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-myApp.controller("policyListController", function($scope, $stateParams,
-                                                    $location, ConfigFactory) {
+myApp.controller("policyListController", ["$scope", "$stateParams", "$location",
+                                          "ConfigFactory",
+                                          function($scope, $stateParams,
+                                                   $location, ConfigFactory) {
     if ($location.path() === "/config/policies") {
         $location.path("/config/policies/list");
     }
@@ -59,14 +61,18 @@ myApp.controller("policyListController", function($scope, $stateParams,
         });
     };
 
-
-
     $scope.getPolicies();
-});
 
-myApp.controller("policyDetailsController", function($scope, $stateParams,
-                                                     ConfigFactory, $state,
-                                                     PolicyTemplateFactory) {
+    // listen to the reload broadcast
+    $scope.$on("piReload", $scope.getPolicies);
+}]);
+
+myApp.controller("policyDetailsController", ["$scope", "$stateParams",
+                                             "ConfigFactory", "$state",
+                                             "PolicyTemplateFactory",
+                                             function($scope, $stateParams,
+                                                      ConfigFactory, $state,
+                                                      PolicyTemplateFactory) {
     // init
     $scope.realms = [];
     $scope.adminRealms = [];
@@ -79,9 +85,11 @@ myApp.controller("policyDetailsController", function($scope, $stateParams,
     $scope.pinodesLoaded = false;
     $scope.policyConditionDefsLoaded = false;
     $scope.scopes = [];
+    $scope.selectedScope = null;
     $scope.viewPolicyTemplates = false;
     $scope.action_filter = "";
     $('html,body').scrollTop(0);
+    $scope.onlySelectedVisible = false;
 
     var check_all_loaded = function() {
         if ($scope.resolversLoaded &&
@@ -412,14 +420,27 @@ myApp.controller("policyDetailsController", function($scope, $stateParams,
                 $scope.presetEditValues2(policy);
             });
         }
-    }
-});
+    };
 
-myApp.controller("tokenConfigController", function ($scope, $location,
-                                                    $rootScope, $state,
-                                                    $stateParams,
-                                                    ConfigFactory,instanceUrl,
-                                                    inform, gettextCatalog) {
+    // test if the accordion group should be open or closed
+    $scope.checkOpenGroup = function(action, pattern) {
+        let pat = escapeRegexp(pattern);
+        let re = RegExp(pat, 'i');
+        return ($scope.actionCheckBox[action.name] ||
+                !$scope.onlySelectedVisible) &&
+            (re.test(action.name) || re.test(action.desc));
+    };
+}]);
+
+myApp.controller("tokenConfigController", ["$scope", "$location", "$rootScope",
+                                           "$state", "$stateParams",
+                                           "ConfigFactory","instanceUrl",
+                                           "inform", "gettextCatalog",
+                                           function ($scope, $location,
+                                                     $rootScope, $state,
+                                                     $stateParams,
+                                                     ConfigFactory,instanceUrl,
+                                                     inform, gettextCatalog) {
     $scope.defaultSMSProvider = "privacyidea.lib.smsprovider.HttpSMSProvider.HttpSMSProvider";
     $scope.tokentype = $stateParams.tokentype || "hotp";
     $scope.form = {};
@@ -518,11 +539,15 @@ myApp.controller("tokenConfigController", function ($scope, $location,
     $scope.getSmtpIdentifiers();
     $scope.getSMSIdentifiers();
     $scope.loadSystemConfig();
-});
-myApp.controller("configController", function ($scope, $location,
-                                               $rootScope, $state,
-                                               ConfigFactory, instanceUrl,
-                                               inform, gettextCatalog) {
+}]);
+
+myApp.controller("configController", ["$scope", "$location", "$rootScope",
+                                      "$state", "ConfigFactory", "instanceUrl",
+                                      "inform", "gettextCatalog",
+                                      function ($scope, $location, $rootScope,
+                                                $state, ConfigFactory,
+                                                instanceUrl, inform,
+                                                gettextCatalog) {
     $scope.instanceUrl = instanceUrl;
     $scope.params = {};
     $('html,body').scrollTop(0);
@@ -741,10 +766,12 @@ myApp.controller("configController", function ($scope, $location,
         $scope.getSystemConfig();
     });
 
-});
+}]);
 
-myApp.controller("PasswdResolverController", function ($scope, ConfigFactory,
-                                                       $state, $stateParams) {
+myApp.controller("PasswdResolverController", ["$scope", "ConfigFactory",
+                                              "$state", "$stateParams",
+                                              function ($scope, ConfigFactory,
+                                                        $state, $stateParams) {
     $scope.params = {
         type: 'passwdresolver',
         fileName: "/etc/passwd"
@@ -768,11 +795,12 @@ myApp.controller("PasswdResolverController", function ($scope, ConfigFactory,
             $state.go("config.resolvers.list");
         });
     };
-});
+}]);
 
-myApp.controller("hostsResolverController", function ($scope,
-                                                      ConfigFactory,
-                                                      $state, $stateParams) {
+myApp.controller("hostsResolverController", ["$scope", "ConfigFactory",
+                                             "$state", "$stateParams",
+                                             function ($scope, ConfigFactory,
+                                                       $state, $stateParams) {
     $scope.params = {
         type: 'hosts',
         filename: "/etc/hosts"
@@ -796,11 +824,13 @@ myApp.controller("hostsResolverController", function ($scope,
             $state.go("config.mresolvers.list");
         });
     };
-});
+}]);
 
-myApp.controller("CAConnectorController", function($scope, ConfigFactory,
-                                                   $state, $rootScope,
-                                                   $location){
+myApp.controller("CAConnectorController", ["$scope", "ConfigFactory", "$state",
+                                           "$rootScope", "$location",
+                                           function($scope, ConfigFactory,
+                                                    $state, $rootScope,
+                                                    $location){
     if ($location.path() === "/config/caconnectors") {
         $location.path("/config/caconnectors/list");
     }
@@ -827,10 +857,12 @@ myApp.controller("CAConnectorController", function($scope, ConfigFactory,
 
     // listen to the reload broadcast
     $scope.$on("piReload", $scope.getCAConnectors);
-});
+}]);
 
-myApp.controller("LocalCAConnectorController", function($scope, $stateParams,
-                                                        ConfigFactory, $state) {
+myApp.controller("LocalCAConnectorController", ["$scope", "$stateParams",
+                                                "ConfigFactory", "$state",
+                                                function($scope, $stateParams,
+                                                         ConfigFactory, $state) {
     $scope.params = {
         type: 'local'
     };
@@ -856,13 +888,15 @@ myApp.controller("LocalCAConnectorController", function($scope, $stateParams,
         });
     };
 
-});
+}]);
 
 
-myApp.controller("machineResolverController", function ($scope,
-                                                        ConfigFactory,
-                                                        $state, $rootScope,
-                                                        $location) {
+myApp.controller("machineResolverController", ["$scope", "ConfigFactory",
+                                               "$state", "$rootScope",
+                                               "$location",
+                                               function ($scope, ConfigFactory,
+                                                         $state, $rootScope,
+                                                         $location) {
     if ($location.path() === "/config/machineresolvers") {
         $location.path("/config/machineresolvers/list");
     }
@@ -888,11 +922,14 @@ myApp.controller("machineResolverController", function ($scope,
 
     // listen to the reload broadcast
     $scope.$on("piReload", $scope.getMachineResolvers);
-});
+}]);
 
-myApp.controller("LdapResolverController", function ($scope, ConfigFactory, $state,
-                                                     $stateParams, inform,
-                                                     gettextCatalog) {
+myApp.controller("LdapResolverController", ["$scope", "ConfigFactory", "$state",
+                                            "$stateParams", "inform",
+                                            "gettextCatalog",
+                                            function ($scope, ConfigFactory,
+                                                      $state, $stateParams,
+                                                      inform, gettextCatalog) {
     /*
      BINDDN, BINDPW, LDAPURI, TIMEOUT, LDAPBASE, LOGINNAMEATTRIBUTE,
      LDAPSEARCHFILTER,
@@ -908,6 +945,7 @@ myApp.controller("LdapResolverController", function ($scope, ConfigFactory, $sta
         CACHE_TIMEOUT: 120,
         NOSCHEMAS: false,
         TLS_VERIFY: true,
+        TLS_VERSION: "2",
         START_TLS: true,
         SERVERPOOL_ROUNDS: 2,
         SERVERPOOL_SKIP: 30
@@ -916,6 +954,10 @@ myApp.controller("LdapResolverController", function ($scope, ConfigFactory, $sta
     $scope.resolvername = $stateParams.resolvername;
     $scope.authtypes = ["Simple", "SASL Digest-MD5", "NTLM"];
     $scope.scopes = ["SUBTREE", "BASE", "LEVEL"];
+    $scope.tls_version_options = [{value: "3", name: "TLS v1.0"},
+                                  {value: "4", name: "TLS v1.1"},
+                                  {value: "5", name: "TLS v1.2"},
+                                  {value: "2", name: "TLS v1.3"}];
 
     $('html,body').scrollTop(0);
 
@@ -982,11 +1024,14 @@ myApp.controller("LdapResolverController", function ($scope, ConfigFactory, $sta
             }
         });
     };
-});
+}]);
 
-myApp.controller("ScimResolverController", function ($scope, ConfigFactory,
-                                                     $state, $stateParams,
-                                                     inform, gettextCatalog) {
+myApp.controller("ScimResolverController", ["$scope", "ConfigFactory", "$state",
+                                            "$stateParams", "inform",
+                                            "gettextCatalog",
+                                            function ($scope, ConfigFactory,
+                                                      $state, $stateParams,
+                                                      inform, gettextCatalog) {
     /*
      Authserver, Resourceserver, Client, Secret
      */
@@ -1024,14 +1069,14 @@ myApp.controller("ScimResolverController", function ($scope, ConfigFactory,
             }
         });
     };
-});
+}]);
 
-myApp.controller("SqlResolverController", function ($scope, ConfigFactory,
-                                                    $state, $stateParams,
-                                                    inform, gettextCatalog) {
-    /*
-
-     */
+myApp.controller("SqlResolverController", ["$scope", "ConfigFactory", "$state",
+                                           "$stateParams", "inform",
+                                           "gettextCatalog",
+                                           function ($scope, ConfigFactory,
+                                                     $state, $stateParams,
+                                                     inform, gettextCatalog) {
     $scope.params = {
         type: 'sqlresolver'
     };
@@ -1106,15 +1151,13 @@ myApp.controller("SqlResolverController", function ($scope, ConfigFactory,
             }
         });
     };
-});
+}]);
 
-myApp.controller("HTTPResolverController", function(
-  $scope,
-  ConfigFactory,
-  $state,
-  $stateParams,
-  inform
-) {
+myApp.controller("HTTPResolverController", ["$scope", "ConfigFactory", "$state",
+                                            "$stateParams", "inform",
+                                            function($scope, ConfigFactory,
+                                                     $state, $stateParams,
+                                                     inform) {
   $scope.params = {
     type: "httpresolver",
     endpoint: "",
@@ -1163,4 +1206,4 @@ myApp.controller("HTTPResolverController", function(
       }
     });
   };
-});
\ No newline at end of file
+}]);
