@@ -18,11 +18,12 @@
  * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-myApp.controller("tokenController", function (TokenFactory, ConfigFactory,
-                                              $scope, $location, AuthFactory,
-                                              instanceUrl,
-                                              $rootScope, gettextCatalog,
-                                              hotkeys) {
+myApp.controller("tokenController", ['TokenFactory', 'ConfigFactory', '$scope',
+                                     '$location', 'AuthFactory', 'instanceUrl',
+                                     '$rootScope',
+                                     function (TokenFactory, ConfigFactory,
+                                               $scope, $location, AuthFactory,
+                                               instanceUrl, $rootScope) {
     $scope.tokensPerPage = $scope.token_page_size;
     $scope.params = {page: 1, sortdir: "asc"};
     $scope.reverse = false;
@@ -99,7 +100,7 @@ myApp.controller("tokenController", function (TokenFactory, ConfigFactory,
         $scope.get();
     });
 
-});
+}]);
 
 
 myApp.controller("tokenAssignController", ['$scope', 'TokenFactory',
@@ -150,6 +151,9 @@ myApp.controller("tokenEnrollController", ["$scope", "TokenFactory", "$timeout",
 
     $scope.qrCodeWidth = 250;
 
+    // Available SMS gateways. We do this here to avoid javascript loops
+    $scope.smsGateways = $scope.getRightsValue('sms_gateways', '').split(' ');
+
     if ($state.includes('token.wizard') && !$scope.show_seed) {
         $scope.qrCodeWidth = 300;
     }
@@ -420,7 +424,6 @@ myApp.controller("tokenEnrollController", ["$scope", "TokenFactory", "$timeout",
     $scope.CATemplates = {};
     $scope.radioCSR = 'csrgenerate';
 
-
     // default enrollment callback
     $scope.callback = function (data) {
         $scope.U2FToken = {};
@@ -509,6 +512,19 @@ myApp.controller("tokenEnrollController", ["$scope", "TokenFactory", "$timeout",
         });
     };
 
+    $scope.sendVerifyResponse = function () {
+        var params = {
+            "serial": $scope.enrolledToken.serial,
+            "verify": $scope.verifyResponse,
+            "type": $scope.form.type
+
+        };
+        TokenFactory.enroll($scope.newUser, params, function (data) {
+            $scope.verifyResponse = "";
+            $scope.callback(data);
+        });
+    };
+
     // Special Token functions
     $scope.sshkeyChanged = function () {
         var keyArr = $scope.form.sshkey.split(" ");
@@ -648,9 +664,11 @@ myApp.controller("tokenEnrollController", ["$scope", "TokenFactory", "$timeout",
 }]);
 
 
-myApp.controller("tokenImportController", function ($scope, Upload,
-                                                    AuthFactory, tokenUrl,
-                                                    ConfigFactory, inform) {
+myApp.controller("tokenImportController", ['$scope', 'Upload', 'AuthFactory',
+                                           'tokenUrl', 'ConfigFactory', 'inform',
+                                           function ($scope, Upload,
+                                                     AuthFactory, tokenUrl,
+                                                     ConfigFactory, inform) {
     $scope.formInit = {
         fileTypes: ["aladdin-xml", "OATH CSV", "Yubikey CSV", "pskc"]
     };
@@ -702,4 +720,4 @@ myApp.controller("tokenImportController", function ($scope, Upload,
                 $scope.uploadProgress = parseInt(100.0 * evt.loaded / evt.total)});
         }
     };
-});
+}]);
